Learn R Programming

Risa (version 1.14.0)

getMSAssayFilenames: Retrieves a vector with the assay filenames corresponding to mass spectrometry.

Description

Given an object from the ISAtab-class, this method retrieves a vector with the assay filenames corresponding to mass spectrometry (identified by having a column called 'Raw Spectral Data File'.

Usage

getMSAssayFilenames(isa)

Arguments

isa
an object from the ISAtab class

Value

A character vector with the assay filenames corresponding to mass spectrometry.

Examples

Run this code
  data.dir <- system.file("extdata", package="Risa")
  isazip <- system.file("extdata","faahKO-metadata.zip", package="Risa")
  faahkoISA <- readISAtab(zipfile = isazip, path = file.path(data.dir,"faahKOISA"), verbose =TRUE)  
  ms.assay.filenames <- getMSAssayFilenames(faahkoISA)

Run the code above in your browser using DataLab