Learn R Programming

Risa (version 1.14.0)

isMSAssay: Indicates if an assay filename corresponds to a mass spectrometry assay.

Description

Indicates if an assay filename corresponds to a mass spectrometry assay.

Usage

isMSAssay(isa, assay.filename)

Arguments

isa
an object from the ISAtab-class.
assay.filename
the filename of an assay file

Value

It retrieves a boolean value indicating wether the assay is a mass spectrometry assay or not.

Examples

Run this code
faahkoISA = readISAtab(find.package("faahKO"))
assay.filename <- faahkoISA["assay.filenames"][[1]]
isMSAssay(faahkoISA, assay.filename)

Run the code above in your browser using DataLab