Learn R Programming

Risa (version 1.14.0)

write.investigation.file: Writes the Investigation File of an ISA-Tab dataset

Description

write.investigation.file reads a ISA-tab file.

Usage

write.investigation.file(isa, path = getwd())

Arguments

isa
the ISA-Tab object (as retrieved by the readISAtab function)
path
the output path in which the study file is going to be written, by default is the working directory

See Also

write.ISAtab, write.study.file, write.assay.file, readISAtab

Examples

Run this code
    ### Example of writing the study file of faahKO ISA-Tab dataset into the temp director
    faahkoISA <- readISAtab(find.package("faahKO"))
    temp = tempdir()
    write.investigation.file(faahkoISA, temp)

Run the code above in your browser using DataLab